#
# spec file for package tumbler
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libtumbler-1-0
%bcond_with libffmpegthumbnailer
Name:           tumbler
Version:        0.1.31
Release:        5.4
Summary:        Thumbnail Management for Xfce
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Graphics/Other
Url:            http://www.xfce.org/
Source:         http://archive.xfce.org/src/apps/%{name}/0.1/%{name}-%{version}.tar.bz2
BuildRequires:  intltool
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
# GdkPibuxf thumbnailer plugin
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
# FreeType2 font thumbnailer plugin
BuildRequires:  freetype2-devel
# JPEG thumbnailer plugin with EXIF support
BuildRequires:  libjpeg-devel
%if %{with libffmpegthumbnailer}
# ffmpeg video thumbnailer plugin
BuildRequires:  pkgconfig(libffmpegthumbnailer)
%endif
# gstreamer video thumbnailer plugin
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
# poppler PDF/PS thumbnailer plugin
BuildRequires:  pkgconfig(poppler-glib)
# ODF thumbnailer plugin
BuildRequires:  pkgconfig(libgsf-1)
# libopenraw thumbnailer plugin
BuildRequires:  pkgconfig(libopenraw-gnome-1.0)
# freedesktop.org cache plugin
BuildRequires:  pkgconfig(libpng)
# OMDB cover plugin
BuildRequires:  pkgconfig(libcurl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tumbler is a D-Bus service for applications to request thumbnails for various
URI schemes and MIME types. It is an implementation of the thumbnail management
D-Bus specification described on http://live.gnome.org/ThumbnailerSpec and
extensible through a plugin interface or via specialized thumbnailer services
implemented in accordance to the thumbnail management D-Bus specification.

%package -n %{libname}
Summary:        Tumbler Library
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}

%description -n %{libname}
This package provides the shared library component of tumbler.

%package devel
Summary:        Development Files for tumbler
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
This package contains the development files needed for developing tumbler
plugins.

%package doc
Summary:        Developer Documentation for tumbler
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the developer documentation for tumbler.

%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{libname} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{libname})
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags} V=1

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%dir %{_sysconfdir}/xdg/tumbler/
%config(noreplace) %{_sysconfdir}/xdg/tumbler/tumbler.rc
%dir %{_libdir}/tumbler-1
%{_libdir}/tumbler-1/tumblerd
%dir %{_libdir}/tumbler-1/plugins
%dir %{_libdir}/tumbler-1/plugins/cache
%{_libdir}/tumbler-1/plugins/cache/tumbler-xdg-cache.so
%{_libdir}/tumbler-1/plugins/cache/tumbler-cache-plugin.so
%if %{with libffmpegthumbnailer}
%{_libdir}/tumbler-1/plugins/tumbler-ffmpeg-thumbnailer.so
%endif
%{_libdir}/tumbler-1/plugins/tumbler-font-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-gst-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-jpeg-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-odf-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-pixbuf-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-poppler-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-raw-thumbnailer.so
%{_libdir}/tumbler-1/plugins/tumbler-cover-thumbnailer.so
%{_datadir}/dbus-1/services/*.service

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libtumbler-1.so.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%{_includedir}/tumbler-1
%{_libdir}/pkgconfig/tumbler-1.pc
%{_libdir}/libtumbler-1.so

%files doc
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/tumbler

%changelog
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.1.31
  - use $XDG_CACHE_HOME/thumbnails as per spec change (bxo#10613)
  - move xdt m4 macros into separate directory
  - update xdt m4 macros
  - bump autotools requirements
  - fix IT_PROG_INTLTOOL warning
  - fix all m4 warnings
  - enable support for video/webm in ffmpeg thumbnailer plugin
    (bxo#10360)
  - translation updates
* Mon May 26 2014 gber@opensuse.org
- update to version 0.1.30
  - only enable keepalive in curl >= 7.25
  - support move/copy operations on directories in the cache
  - send the cache operation replies after they are completed
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 0.1.29
  - fix memory corruption on 64bit
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 0.1.28
  - set nice value of tumblerd to 19
  - fix rendering from pdfs with thumbnail
  - add more supported types for gst thumbnailer
  - some additional debug checks for bug #9766 and minor
    optimizations
  - fix deprecating warning with glib 2.36
  - include string.h
  - translation updates
- remove obsolete tumbler-libpng16.patch
* Fri Feb 15 2013 pgajdos@suse.com
- build also with libpng16
  * libpng16.patch
* Tue Jan 15 2013 gber@opensuse.org
- build the OMDB cover thumbnailer (although disabled by default
  for privacy reasons)
* Sat Jan 12 2013 gber@opensuse.org
- update to version 0.1.27
  - autotools updates
  - remove unmaintained translations
  - fix build when using -Wl,-z,defs
  - add cover-thumbnailer for movies
  - add config file system to control thumbnailing plugins
  - release thumbnail in gst thumbnailer
* Mon Dec 17 2012 gber@opensuse.org
- update to version 0.1.26
  - remove INSTALL
  - directly render the capture in the correct size
  - new gstreamer thumbnailer based on totem-thumbnailer
  - disable http and cdda schemes as well
  - add support for MPEG2 transport streams
  - rotate jpeg thumbnails
  - plug small leak
  - don't use collate to check strings
  - release lifecycle manager during early exit
  - don't abort with warnings in debug mode
  - clear 2.32 mutex memory leak
  - drop unneeded vfs schemes
  - work with an array to store the strings
  - don't use GString for a simple concat
  - make registry dump a bit smaller
  - don't use deprecated glib 2.32 API
  - rotate pixbuf loader images
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 0.1.25
  - remove some unused m4 macros
  - add or fix missing licenses
  - translation updates
* Sat Mar 31 2012 gber@opensuse.org
- update to version 0.1.24
  - link all plugins that use rint() against libm
  - call dbus_g_thread_init() to fix threading issues
  - add application/vnd.rn-realmedia to the ffmpeg plugin
  - explicitly link against gmodule
  - avoid accessing list elements after they have been freed
  - make sure to include PLATFORM flags everywhere
  - translation updates
* Tue Mar 27 2012 gber@opensuse.org
- split of -lang and shared library subpackages in order to comply
  with the shread library packaging policy
- enable ODF and RAW plugins and add the option to build the ffmpeg
  plugin
- correct dependencies
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Dec  4 2011 gber@opensuse.org
- update to version 0.1.23
  - fix generation of video images by starting the pipeline
  - add an ODF thumbnailer plugin
  - add support for OpenRaster images in the ODF thumbnailer
  - add a raw image thumbnailer plugin
  - exit the xdg thumbnailer nicely with corrupt png files
  - avoid huge thumbnails from libjpeg
  - optimize the pixbuf thumbnailer
  - bugfixes
  - translation updates
- dropped obsolete tumbler-0.1.22-fix-video-thumbnails.patch
* Tue Sep 27 2011 gber@opensuse.org
- added tumbler-0.1.22-fix-video-thumbnails.patch in order to fix
  the generation of video images by starting the pipeline
- build the gstreamer plugin now that it actually works
* Wed Sep 21 2011 gber@opensuse.org
- update to version 0.1.22
  - add coding style documentation
  - add a GStreamer-based thumbnailer for video thumbnails
  - avoid GdkPixbuf functions deprecated in poppler >= 0.17
  - translation updates
- dropped obsolete tumbler-poppler-0.18.patch,
  tumbler-poppler-0.18-bis.patch
* Tue Sep 20 2011 vuntz@opensuse.org
- Add tumbler-poppler-0.18.patch: fix build with poppler 0.17/0.18.
  Patch taken from git.
- Add tumbler-poppler-0.18-bis.patch: second part of the fix, not
  in git yet.
* Fri Feb 18 2011 gber@opensuse.org
- update to version 0.1.21
  - version bump to override incompatibly versioned packages for
    Maemo
  - quit tumbler after at least 5 minutes of inactivity
  - update to latest revision of the thumbnail management D-Bus
    specification where Cleanup() takes an array of base URIs
    instead of just one
  - translation updates
* Mon Jan 17 2011 gber@opensuse.org
- update to version 0.1.6
  - bugfixes
* Sun Dec 26 2010 gber@opensuse.org
- corrected license
- corrected groups
- improved summaries
- show compiler output
- remove unsupported locales
- enabled plugins:
  - GdkPixbuf thumbnailer
  - FreeType font thumbnailer
  - JPEG thumbnailer with EXIF support
  - PDF/PS thumbnailer plugin
  - Freedesktop.org cache
* Thu Dec  2 2010 prusnak@opensuse.org
- updated to 0.1.4
  - Use LGPL instead of GPL license headers in the library (bug #6781).
- updated to 0.1.3
  - Link plugins against libtumbler-1. Should fix builds with
  - -as-needed.
  - Move tumblerd into $libdir/tumbler-1.
  - Add support for arbitrary URI shemes in the poppler plugin.
  - Translation updates: Basque, Indonesian, Swedish, German, Russian,
    Galician, Uyghur, Chinese (Taiwan), Ukrainian, Finnish, Catalan
    (Valencian), Danish, Japanese, Kazakh, Italian, Portuguese,
- updated to 0.1.2
  - Add a new PDF/PostScript thumbnailer plugin based on poppler.
  - Add a new video thumbnailer plugin using libffmpegthumbnailer.
  - Handle missing URIs/MIME types in thumbnailer requests by reporting
    them back to the client application as an error.
  - Don't use dbus_connection_send from threads. Use g_idle_add()
    instead.
  - Improve tumblerd's startup significantly by optimizing the code
    dealing with updating the supported URI schemes and MIME types.
  - Avoid compiler warnings due to global name shadowing.
  - Translation updates: Traditional Chinese, Punjabi, Bengali, Sinhala,
    French, Chinese (China) and more.
* Wed Jan 13 2010 prusnak@suse.cz
- created package (version 0.1.1)
